M10QueryServiceClient

Struct M10QueryServiceClient 

pub struct M10QueryServiceClient<T> { /* private fields */ }
/ Service for querying the ledger.

Implementations

Source

impl M10QueryServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<M10QueryServiceClient<Channel>, Error>
where D: TryInto<Endpoint>, <D as TryInto<Endpoint>>::Error: Into<Box<dyn Error + Sync + Send>>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> M10QueryServiceClient<T>

pub fn new(inner: T) -> M10QueryServiceClient<T>

pub fn with_origin(inner: T, origin: Uri) -> M10QueryServiceClient<T>

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> M10QueryServiceClient<InterceptedService<T, F>>

pub fn send_compressed( self, encoding: CompressionEncoding, ) -> M10QueryServiceClient<T>

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> M10QueryServiceClient<T>

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> M10QueryServiceClient<T>

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> M10QueryServiceClient<T>

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn get_transfer( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<FinalizedTransfer>, Status>

Transfers / Retrieves a specific transfer by ID.

pub async fn list_transfers( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<FinalizedTransfers>, Status>

/ Retrieves a list of transfers.

pub async fn observe_transfers( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Streaming<FinalizedTransactions>>, Status>

/ Observes transfers. / Param: RequestEnvelope should contain ObserveAccountsRequest

pub async fn get_indexed_account( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<IndexedAccount>, Status>

Accounts / Retrieves an indexed account by ID.

pub async fn get_account_metadata( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<AccountMetadata>, Status>

/ Retrieve account metadata.

pub async fn get_account_info( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<AccountInfo>, Status>

/ Retrieve account information.

pub async fn list_account_metadata( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<ListAccountMetadataResponse>, Status>

/ Lists AccountMetadata.

pub async fn observe_accounts( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Streaming<FinalizedTransactions>>, Status>

/ Observes account changes. / Param: RequestEnvelope should contain ObserveAccountsRequest

pub async fn get_action( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Action>, Status>

/ Actions / Retrieves a specific action by ID.

pub async fn list_actions( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Actions>, Status>

/ Retrieves a list of actions.

pub async fn observe_actions( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Streaming<FinalizedTransactions>>, Status>

/ Observe actions. / Param: RequestEnvelope should contain ObserveActionsRequest

pub async fn get_chain_info( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<ChainInfo>, Status>

/ Retrieves chain information.

pub async fn get_transaction( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<FinalizedTransaction>, Status>

/ Transactions / Request a specific transaction by ID / Param: RequestEnvelope should contain GetTransactionRequest

pub async fn list_transactions( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<FinalizedTransactions>, Status>

/ List transactions. Param: RequestEnvelope should contain ListTransactionsRequest

pub async fn group_transactions( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<GroupedFinalizedTransactions>, Status>

/ Group transactions. / ID Param: RequestEnvelope should contain GroupTransactionsRequest

pub async fn get_account_set( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<AccountSet>, Status>

/ AccountSet / Retrieve an AccountSet.

pub async fn list_account_sets( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<ListAccountSetsResponse>, Status>

/ List AccountSets.

pub async fn get_role_binding( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<RoleBinding>, Status>

/ RoleBinding / Retrieve role binding.

pub async fn list_role_bindings( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<ListRoleBindingsResponse>, Status>

/ List role bindings.

pub async fn get_role( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Role>, Status>

RoleBinding / Retrieve a role.

pub async fn list_roles( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<ListRolesResponse>, Status>

/ List roles.

pub async fn observe_resources( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Streaming<FinalizedTransactions>>, Status>

Resources Request to observe all resources processed by the ledger / Observes resources. / Param: RequestEnvelope should contain ObserveResourcesRequest

pub async fn observe_metrics( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Streaming<TransactionMetrics>>, Status>

Metrics Request to observe metrics data processed by the ledger / Observes metrics. / Param: RequestEnvelope should contain ObserveAccountsRequest

pub async fn list_banks( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<ListBanksResponse>, Status>

Banks / Lists banks. / Param: RequestEnvelope should contain ListBanksRequest

pub async fn get_bank( &mut self, request: impl IntoRequest<RequestEnvelope>, ) -> Result<Response<Bank>, Status>

/ Retrieves a bank. / Param: RequestEnvelope should contain Bank

pub async fn get_offline_key( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<OfflineKey>, Status>

Offline / Retrieves an offline key.