#[repr(i32)]pub enum Code {
Show 22 variants
Unknown = 0,
Unimplemented = 1,
NotFound = 2,
AlreadyExists = 3,
Unauthorized = 4,
BadRequest = 5,
InvalidRequestType = 6,
InvalidAccountId = 7,
InvalidTransfer = 8,
MessageTooLarge = 10,
InvalidSignature = 11,
VerificationFailed = 12,
ReplayProtection = 20,
InvalidExpression = 21,
IncorrectType = 22,
AccountFrozen = 23,
UnmodifiedState = 24,
InsufficientBalance = 25,
BalanceOverflow = 26,
AccountDepthExceeded = 27,
HoldingLimitExceeded = 28,
InvalidTarget = 30,
}Variants
Unknown = 0
Generic status codes
Unimplemented = 1
NotFound = 2
AlreadyExists = 3
BadRequest = 5
Request is malformed
InvalidRequestType = 6
Invalid/unsupported transaction request type
InvalidAccountId = 7
Invalid account ID
InvalidTransfer = 8
Invalid transfer parameters (amount, accounts, etc)
MessageTooLarge = 10
The request message was too large to be processed.
InvalidSignature = 11
The request signature does not match the request payload
VerificationFailed = 12
Signature verification failed
ReplayProtection = 20
Replay protection was triggered, e.g. nonce reuse, bad block window
InvalidExpression = 21
Invalid expression used
IncorrectType = 22
AccountFrozen = 23
Ledger-specific status codes
UnmodifiedState = 24
InsufficientBalance = 25
BalanceOverflow = 26
AccountDepthExceeded = 27
HoldingLimitExceeded = 28
InvalidTarget = 30
Action specific status codes
Implementations
Sourceimpl Code
impl Code
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Code>
pub fn from_str_name(value: &str) -> Option<Code>
Creates an enum from field names used in the ProtoBuf definition.